@@ -1,4 +1,3 @@
-import imghdr
 from typing import Optional
 
 from urllib.request import urlopen, Request
@@ -16,6 +15,20 @@ from designer.utilities import Vec2D
 from designer.utilities.util import _anchor_offset
 from designer.utilities.gif_image import GifImage
 
+try:
+    import imghdr
+    ALT_MODE = False
+    FileNotFoundError
+except:
+    FileNotFoundError = Exception
+    ALT_MODE = True
+    # TODO: Figure out how to do imghdr's gif stuff in skulpt
+    class imghdr:
+        def what(self, path, data):
+            if isinstance(path, str):
+                return path.endswith('.gif')
+            else:
+                return False
 
 class Image(DesignerObject):
     _USER_AGENT = "Designer Game Library for Python"
@@ -100,6 +113,9 @@ class Image(DesignerObject):
                     raise ValueError(f"Unexpected error while loading url: {self._filename!r}")
                 raise ValueError(f"Unexpected error while loading image from filename: {self._filename!r}")
 
+    def _load_image_url_only(self):
+        self._internal_image = InternalImage(filename=self._filename)
+
     def _recalculate_offset(self):
         """
         Recalculates this designer object's offset based on its position, transform
@@ -138,6 +154,8 @@ class Image(DesignerObject):
             source = pygame.transform.rotate(source, angle).convert_alpha()
             new = source.get_rect().center
             self._transform_offset = old - new
+        else:
+            self._transform_offset = Vec2D(0, 0)
         # Finish updates
         self._transform_image = source
         self._recalculate_offset()
@@ -197,3 +215,6 @@ def image(path, x=None, y=None, anchor='center', **kwargs):
         x, y = x
     return Image((x, y), path, anchor, **kwargs)
 
+
+if ALT_MODE:
+    Image._load_image = Image._load_image_url_only
